# bitwardenrs_ldap

Rootless Bitwarden_RS - Self-hosted password manager

[![Build Status](https://img.shields.io/drone/build/docker/bitwardenrs_ldap?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/docker/bitwardenrs_ldap)
[![Docker Hub](https://img.shields.io/badge/docker-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/xoxys/bitwardenrs_ldap)
[![Quay.io](https://img.shields.io/badge/quay-latest-blue.svg?logo=docker&logoColor=white)](https://quay.io/repository/thegeeklab/bitwardenrs_ldap)
[![Source: Gitea](https://img.shields.io/badge/source-gitea-blue.svg?logo=gitea&logoColor=white)](https://gitea.rknet.org/docker/bitwardenrs_ldap)
[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/docker/bitwardenrs_ldap/src/branch/master/LICENSE)

This is a custom Docker image for [bitwarden_rs_ldap](https://github.com/ViViDboarder/bitwarden_rs_ldap) a simple LDAP connector for bitwarden_rs.

## Usage

### Docker Compose

```Yaml
---
version: '3'

services:
  postgres:
    container_name: postgres
    image: postgres
    environment:
      POSTGRES_DB: bitwarden
      POSTGRES_PASSWORD: pass
      POSTGRES_USER: user

  ldap:
    container_name: ldap
    image: osixia/openldap

  bitwardenrs:
    container_name: bitwardenrs_server
    image: xoxys/bitwardenrs:latest
    depends_on:
      - postgres
    ports:
      - "80:8080"
    volumes:
      - data:/app/data
    environment:
      BITWARDENRS_DATABASE_URL: postgresql://user:pass@postgres:5432/bitwarden
      BITWARDENRS_ADMIN_TOKEN: my_secure_token

  bitwardenrs_ldap:
    container_name: ldap_sync
    restart: always
    image: xoxys/bitwardenrs_ldap:latest
    depends_on:
      - bitwardenrs
      - ldap
    environment:
      BITWARDENRS_LDAP_BITWARDEN_URL: http://bitwardenrs_server:8080
      BITWARDENRS_LDAP_BITWARDEN_ADMIN_TOKEN: my_secure_token
      BITWARDENRS_LDAP_HOST: ldap
      BITWARDENRS_LDAP_SSL: "False"
      BITWARDENRS_LDAP_BIND_DN: "cn=admin,dc=example,dc=org"
      BITWARDENRS_LDAP_SEARCH_BASE_DN: "dc=example,dc=org"
      BITWARDENRS_LDAP_BIND_PASSWORD: admin

volumes:
  data:
    driver: local
```

## Configuration

```Shell
BITWARDENRS_LDAP_BITWARDEN_URL=
BITWARDENRS_LDAP_BITWARDEN_ADMIN_TOKEN=
BITWARDENRS_LDAP_HOST=
BITWARDENRS_LDAP_SCHEME=
BITWARDENRS_LDAP_SSL=True
BITWARDENRS_LDAP_PORT=
BITWARDENRS_LDAP_BIND_DN=
BITWARDENRS_LDAP_BIND_PASSWORD=
BITWARDENRS_LDAP_SEARCH_BASE_DN=
BITWARDENRS_LDAP_SEARCH_FILTER="(&(objectClass=*)(uid=*))"
BITWARDENRS_LDAP_MAIL_FIELD=mail
BITWARDENRS_LDAP_SYNC_INTERVAL_SECONDS=60
BITWARDENRS_LDAP_SYNC_LOOP=True
```

## License

This project is licensed under the MIT License - see the [LICENSE](https://gitea.rknet.org/docker/bitwardenrs_ldap/src/branch/master/LICENSE) file for details.

## Maintainers and Contributors

[Robert Kaussow](https://gitea.rknet.org/xoxys)
